Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - f -

- filename_colors_in : CCDBG_Build_opt
- filename_graph_in : CDBG_Build_opt
- filename_ref_in : CDBG_Build_opt
- filename_seq_in : CDBG_Build_opt
- find() : CompactedDBG< Unitig_data_t, Graph_data_t >
- findUnitig() : CompactedDBG< Unitig_data_t, Graph_data_t >
- forwardBase() : Kmer
- ForwardCDBG() : ForwardCDBG< Unitig_data_t, Graph_data_t, is_const >